@@ -50,6 +50,6 @@ def to_table(rows, project=None, dataset=None, table=None, add_inserted_at=True)
     if add_inserted_at:
         _add_inserted_at_field(rows)
 
-    errors = bq_client.insert_rows(client.get_table(bq_table), rows)
+    errors = bq_client.insert_rows(bq_client.get_table(bq_table), rows)
     if errors:
         raise InsertionError(errors)
